tiled.queries.Key
=================

.. currentmodule:: tiled.queries

.. autoclass:: Key

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Key.__init__
   
   

   
   
   